@@ -4,9 +4,9 @@
 
 #include "AuthenticatedEncryptionKeyModel.h"
 
+// Kaidan
 #include "Algorithms.h"
 #include "EncryptionController.h"
-#include "FutureUtils.h"
 
 AuthenticatedEncryptionKeyModel::AuthenticatedEncryptionKeyModel(QObject *parent)
     : EncryptionKeyModel(parent)
@@ -91,7 +91,7 @@ void AuthenticatedEncryptionKeyModel::handleDevicesChanged(const QString &accoun
 
 void AuthenticatedEncryptionKeyModel::updateOwnKey()
 {
-    await(EncryptionController::instance()->ownDevice(accountJid()), this, [this](EncryptionController::OwnDevice &&ownDevice) {
+    EncryptionController::instance()->ownDevice(accountJid()).then(this, [this](EncryptionController::OwnDevice &&ownDevice) {
         beginInsertRows(QModelIndex(), 0, 0);
         m_ownKey = {ownDevice.label + QStringLiteral(" · ") + tr("This device"), ownDevice.keyId};
         endInsertRows();
@@ -100,31 +100,31 @@ void AuthenticatedEncryptionKeyModel::updateOwnKey()
 
 void AuthenticatedEncryptionKeyModel::updateKeys()
 {
-    await(EncryptionController::instance()->keys(accountJid(), {accountJid()}, QXmpp::TrustLevel::Authenticated),
-          this,
-          [this](QHash<QString, QHash<QString, QXmpp::TrustLevel>> &&keys) {
-              const auto keyIds = keys.value(accountJid()).keys();
+    EncryptionController::instance()
+        ->keys(accountJid(), {accountJid()}, QXmpp::TrustLevel::Authenticated)
+        .then(this, [this](QHash<QString, QHash<QString, QXmpp::TrustLevel>> &&keys) {
+            const auto keyIds = keys.value(accountJid()).keys();
 
-              auto authenticatedKeys = transform(keyIds, [](const QString &keyId) {
-                  return Key{{}, keyId};
-              });
+            auto authenticatedKeys = transform(keyIds, [](const QString &keyId) {
+                return Key{{}, keyId};
+            });
 
-              await(EncryptionController::instance()->devices(accountJid(), {accountJid()}),
-                    this,
-                    [this, authenticatedKeys](QList<EncryptionController::Device> &&devices) mutable {
-                        for (const auto &device : std::as_const(devices)) {
-                            for (auto &authenticatedKey : authenticatedKeys) {
-                                if (device.keyId == authenticatedKey.id) {
-                                    authenticatedKey.deviceLabel = device.label;
-                                }
+            EncryptionController::instance()
+                ->devices(accountJid(), {accountJid()})
+                .then(this, [this, authenticatedKeys](QList<EncryptionController::Device> &&devices) mutable {
+                    for (const auto &device : std::as_const(devices)) {
+                        for (auto &authenticatedKey : authenticatedKeys) {
+                            if (device.keyId == authenticatedKey.id) {
+                                authenticatedKey.deviceLabel = device.label;
                             }
                         }
+                    }
 
-                        beginResetModel();
-                        m_keys = {authenticatedKeys.cbegin(), authenticatedKeys.cend()};
-                        endResetModel();
-                    });
-          });
+                    beginResetModel();
+                    m_keys = {authenticatedKeys.cbegin(), authenticatedKeys.cend()};
+                    endResetModel();
+                });
+        });
 }
 
 #include "moc_AuthenticatedEncryptionKeyModel.cpp"
