@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "Blocking.h"
+
 // Qt
 #include <QSqlQuery>
 // QXmpp
@@ -10,18 +11,13 @@
 // Kaidan
 #include "AccountManager.h"
 #include "Algorithms.h"
-#include "FutureUtils.h"
 #include "Globals.h"
 #include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "SqlUtils.h"
 
 using namespace SqlUtils;
 
-auto debug()
-{
-    return qDebug() << "[Blocking]";
-}
-
 auto determineJidType(const QString &jid)
 {
     using Type = BlockingModel::JidType;
@@ -136,7 +132,7 @@ void BlockingController::subscribeToBlocklist()
     m_subscribed = true;
 
     // load blocklist from database
-    await(m_db->blockedJids(AccountManager::instance()->jid()), this, [this](auto result) {
+    m_db->blockedJids(AccountManager::instance()->account().jid).then(this, [this](QList<QString> result) {
         handleBlocklist({Blocklist::Db, std::move(result)});
     });
 
@@ -204,7 +200,7 @@ void BlockingController::handleXmppBlocklistResult(QXmppBlockingManager::Blockli
             handleBlocklist({Blocklist::Xmpp, QList<QString>()});
         }
 
-        debug() << "Error fetching blocklist:" << error->description;
+        qCDebug(KAIDAN_CORE_LOG) << "Error fetching blocklist:" << error->description;
     } else {
         // success
         handleBlocklist({Blocklist::Xmpp, std::get<QXmppBlocklist>(result).entries()});
@@ -242,7 +238,7 @@ void BlockingController::updateDbBlocklist(const QList<QString> &blockedJids)
         // skip if we already know that the db version is up to date
         return;
     }
-    m_db->resetBlockedJids(AccountManager::instance()->jid(), blockedJids);
+    m_db->resetBlockedJids(AccountManager::instance()->account().jid, blockedJids);
 }
 
 void BlockingController::onJidsBlocked(const QList<QString> &jids)
@@ -250,7 +246,7 @@ void BlockingController::onJidsBlocked(const QList<QString> &jids)
     Q_ASSERT(m_blocklist);
     Q_ASSERT(m_blocklist->source == Blocklist::Xmpp);
 
-    m_db->addBlockedJids(AccountManager::instance()->jid(), jids);
+    m_db->addBlockedJids(AccountManager::instance()->account().jid, jids);
 
     m_blocklist->jids.append(jids);
     makeUnique(m_blocklist->jids);
@@ -267,7 +263,7 @@ void BlockingController::onJidsUnblocked(const QList<QString> &jids)
     Q_ASSERT(m_blocklist);
     Q_ASSERT(m_blocklist->source == Blocklist::Xmpp);
 
-    m_db->removeBlockedJids(AccountManager::instance()->jid(), jids);
+    m_db->removeBlockedJids(AccountManager::instance()->account().jid, jids);
 
     for (const auto &jid : jids) {
         m_blocklist->jids.removeOne(jid);
@@ -441,7 +437,7 @@ BlockingAction::BlockingAction(QObject *parent)
 
 void BlockingAction::block(const QString &jid)
 {
-    debug() << "Blocking" << jid;
+    qCDebug(KAIDAN_CORE_LOG) << "Blocking" << jid;
     setRunning(m_running + 1);
     callRemoteTask(
         Kaidan::instance()->client(),
@@ -454,7 +450,7 @@ void BlockingAction::block(const QString &jid)
             if (auto *error = std::get_if<QXmppError>(&result)) {
                 Q_EMIT errorOccurred(jid, true, error->description);
             } else {
-                debug() << "Blocked" << jid;
+                qCDebug(KAIDAN_CORE_LOG) << "Blocked" << jid;
                 Q_EMIT succeeded(jid, true);
             }
 
@@ -464,7 +460,7 @@ void BlockingAction::block(const QString &jid)
 
 void BlockingAction::unblock(const QString &jid)
 {
-    debug() << "Unblocking" << jid;
+    qCDebug(KAIDAN_CORE_LOG) << "Unblocking" << jid;
     setRunning(m_running + 1);
     callRemoteTask(
         Kaidan::instance()->client(),
@@ -477,7 +473,7 @@ void BlockingAction::unblock(const QString &jid)
             if (auto *error = std::get_if<QXmppError>(&result)) {
                 Q_EMIT errorOccurred(jid, false, error->description);
             } else {
-                debug() << "Unblocked" << jid;
+                qCDebug(KAIDAN_CORE_LOG) << "Unblocked" << jid;
                 Q_EMIT succeeded(jid, false);
             }
 
