@@ -8,8 +8,6 @@
 
 #include "MessageDb.h"
 
-// C++
-#include <ranges>
 // Qt
 #include <QBuffer>
 #include <QFile>
@@ -28,6 +26,7 @@
 #include "Globals.h"
 #include "GroupChatUser.h"
 #include "GroupChatUserDb.h"
+#include "KaidanCoreLog.h"
 #include "TrustDb.h"
 
 Q_DECLARE_METATYPE(QXmpp::Cipher)
@@ -38,11 +37,6 @@ Q_DECLARE_METATYPE(QXmppFileShare::Disposition)
 
 using std::ranges::find;
 
-static auto debug()
-{
-    return qDebug() << "[MessageDb]";
-}
-
 template<typename T>
 QVariant optionalToVariant(std::optional<T> value)
 {
@@ -164,7 +158,7 @@ QList<Message> MessageDb::_fetchMessagesFromQuery(QSqlQuery &query)
         }
 
         msg.timestamp = QDateTime::fromString(query.value(idxTimestamp).toString(), Qt::ISODate);
-        msg.body = query.value(idxBody).toString();
+        msg.setPreparedBody(query.value(idxBody).toString());
         msg.encryption = query.value(idxEncryption).value<Encryption::Enum>();
         msg.senderKey = query.value(idxSenderKey).toByteArray();
         msg.deliveryState = query.value(idxDeliveryState).value<Enums::DeliveryState>();
@@ -233,8 +227,8 @@ QSqlRecord MessageDb::createUpdateRecord(const Message &oldMsg, const Message &n
     if (oldMsg.timestamp != newMsg.timestamp) {
         rec.append(createSqlField(QStringLiteral("timestamp"), newMsg.timestamp.toString(Qt::ISODateWithMs)));
     }
-    if (oldMsg.body != newMsg.body) {
-        rec.append(createSqlField(QStringLiteral("body"), newMsg.body));
+    if (oldMsg.body() != newMsg.body()) {
+        rec.append(createSqlField(QStringLiteral("body"), newMsg.body()));
     }
     if (oldMsg.encryption != newMsg.encryption) {
         rec.append(createSqlField(QStringLiteral("encryption"), newMsg.encryption));
@@ -847,7 +841,7 @@ QFuture<void> MessageDb::attachFileSources(const QString &accountJid,
                   {{u":accountJid", accountJid}, {u":chatJid", chatJid}, {u":id", messageId}});
         auto msgs = _fetchMessagesFromQuery(query);
         if (msgs.empty()) {
-            debug() << "Could not find message with ID" << messageId << "to attach file sources.";
+            qCDebug(KAIDAN_CORE_LOG) << "Could not find message with ID" << messageId << "to attach file sources.";
             return;
         }
         _fetchAdditionalData(msgs);
@@ -857,7 +851,8 @@ QFuture<void> MessageDb::attachFileSources(const QString &accountJid,
         // find file with external ID
         auto fileItr = find(message.files, externalFileId, &File::externalId);
         if (fileItr == message.files.end()) {
-            debug() << "Could not attach sources to message with ID" << messageId << ": No file with external ID of" << externalFileId << "found.";
+            qCDebug(KAIDAN_CORE_LOG) << "Could not attach sources to message with ID" << messageId << ": No file with external ID of" << externalFileId
+                                     << "found.";
             return;
         }
         auto &file = *fileItr;
@@ -978,7 +973,7 @@ void MessageDb::_addMessage(const Message &message)
         {u"stanzaId", message.stanzaId},
         {u"replaceId", message.replaceId},
         {u"timestamp", message.timestamp.toString(Qt::ISODateWithMs)},
-        {u"body", message.body},
+        {u"body", message.body()},
         {u"encryption", message.encryption},
         {u"senderKey", message.senderKey},
         {u"deliveryState", int(message.deliveryState)},
